import 'dart:async';

import 'package:flutter/material.dart';
import 'package:uuid/uuid.dart';
import 'package:rehana/dialogs/base.dart';

class DialogService {
  Map<String, Completer> _dialogCompleter;

  String _createNewDialogCompleter() {
    if (this._dialogCompleter == null) {
      this._dialogCompleter = new Map();
    }
    var uuid = Uuid().v1();
    this._dialogCompleter.putIfAbsent(uuid, () => Completer());
    return uuid;
  }

  Completer getCompleter(String id) {
    return this._dialogCompleter.containsKey(id)
        ? this._dialogCompleter[id]
        : null;
  }

  Future onDialogComplete(String id) {
    return this._dialogCompleter.containsKey(id)
        ? this._dialogCompleter[id].future
        : null;
  }

  /// Calls the dialog listener and returns Dialog Completer ID.
  String showDialog(BuildContext context, BaseDialog dialog, {dynamic data}) {
    String uuid = this._createNewDialogCompleter();

    if (data != null) {
      dialog.show(context, uuid, data: data);
    } else {
      dialog.show(context, uuid);
    }

    return uuid; //getCompleter(uuid).future;
  }

  /// Completes the _dialogCompleter to resume the Future's execution call
  void completeDialog(
      {BuildContext context, String completerId, dynamic result, pop = true}) {
    if (_dialogCompleter.containsKey(completerId)) {
      if (pop) {
        try {
          Navigator.of(context, rootNavigator: true).pop();
        } catch (e) {}
      }
      _dialogCompleter[completerId].complete(result);
      _dialogCompleter[completerId] = null;
      _dialogCompleter.remove(completerId);
    }
  }
}
