import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';

class FlexibleTextField extends StatelessWidget {
  final InputDecoration decoration;
  final bool obscureText;
  final bool readOnly;
  final TextEditingController controller;
  final TextInputType keyboardType;
  final int minLength;
  final List<int> fixedLengths;

  FlexibleTextField(
      {Key key,
      this.decoration,
      this.obscureText = false,
      this.readOnly = false,
      this.controller,
      this.keyboardType = TextInputType.text,
      this.minLength = 0,
      this.fixedLengths})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return new Flexible(
        child: new TextFormField(
      keyboardType: keyboardType,
      validator: (value) {
        if (this.fixedLengths != null &&
            !this.fixedLengths.contains(controller.text.length)) {
          String lengths = this.fixedLengths.map((x) => x.toString()).reduce(
              (value, element) =>
                  (value != null ? value + ',' : '') + element.toString());
          if (this.fixedLengths.length == 1) {
            return 'Length should be $lengths';
          } else {
            return 'Length should be one of $lengths';
          }
        } else if (value.length < this.minLength) {
          if (this.minLength == 1) {
            return 'Enter value';
          } else {
            return 'Length should be at least ${this.minLength}';
          }
        }
        return null;
      },
      obscureText: obscureText != null ? obscureText : false,
      readOnly: readOnly != null ? readOnly : false,
      decoration: decoration,
      controller: controller,
    ));
  }
}
